EasyAccounts class
Account CRUD for EasyLanisClient (no Riverpod).
Constructors
-
EasyAccounts({required LanisDatabase? db, required LanisConfig config, required bool ephemeral, Future<
void> onRemoveActive(int id)?, Future<void> onAccountTypeChanged(int id)?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
{required int schoolId, required String username, required String password, AccountType? accountType}) → Future< int> -
list(
) → Future< List< AccountSummary> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
int id) → Future< void> -
setAccountType(
int id, AccountType type) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
updatePassword(
int id, String password) → Future< void> -
validateCredentials(
{required int schoolId, required String username, required String password}) → Future< String> - Probes credentials against SPH without persisting an account.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited