EasyParsers class

Lazy registry of applet parsers for EasyLanisClient.

Constructors

EasyParsers({required AppletContext ctx, required Future<bool> isConnected()})

Properties

calendar CalendarParser
no setter
conversations ConversationsParser
no setter
dataStorage DataStorageParser
no setter
hashCode int
The hash code for this object.
no setterinherited
lessonsStudent LessonsStudentParser
no setter
lessonsTeacher LessonsTeacherParser
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
studyGroups StudyGroupsStudentParser
no setter
substitutions SubstitutionsParser
no setter
timetable TimetableStudentParser
no setter

Methods

disposeAll() → void
forApplet(String phpUrl) AppletParser
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited