EasySettings class
Shared and per-account settings for EasyLanisClient.
Constructors
- EasySettings({required LanisDatabase db, required int? activeAccountId})
Properties
- account → TypedSettings?
-
Per-account settings for the logged-in account, or null when none selected.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited