AppletContext class

Runtime context for applet parsers (session + account-scoped settings).

Constructors

AppletContext({required LanisSession session, required LanisDatabase database, required ClearTextAccount account, required TypedSettings accountSettings})

Properties

account ClearTextAccount
final
accountId int
no setter
accountSettings TypedSettings
final
database LanisDatabase
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session LanisSession
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited