AppletParser<T> class

Base class for SPH applet parsers (Dart-only, no Flutter).

Implementers
Available extensions

Constructors

AppletParser(AppletContext ctx, AppletMeta appletMeta, {required Future<bool> isConnected()})

Properties

appletMeta AppletMeta
final
ctx AppletContext
final
hashCode int
The hash code for this object.
no setterinherited
isConnected Future<bool> Function()
final
isEmpty bool
getter/setter pair
latestResponse FetcherResponse<T>?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream AppletResponseStream<T>
no setter

Methods

addResponse(FetcherResponse<T> data) → void
dispose() → void
fetch({bool forceRefresh = false}) Future<FetcherResponse<T>>

Available on AppletParser<T>, provided by the AppletParserFetch extension

fetchData({bool forceRefresh = false, bool secondTry = false}) Future<void>
getHome() Future<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startAutoRefresh() → void
Starts periodic refresh. Safe to call repeatedly.
stopAutoRefresh() → void
Stops periodic refresh while the applet is off-screen.
timerCallback(Timer timer) → void
toString() String
A string representation of this object.
inherited
typeFromJson(String json) → T

Operators

operator ==(Object other) bool
The equality operator.
inherited