Conversation class

Constructors

Conversation({required bool groupChat, required bool onlyPrivateAnswers, required bool noReply, required UnparsedMessage parent, required int countParents, required int countStudents, required int countTeachers, required List<KnownParticipant> knownParticipants, required int msgLastRefresh, List<UnparsedMessage> replies = const []})
const

Properties

countParents int
final
countStudents int
final
countTeachers int
final
groupChat bool
final
hashCode int
The hash code for this object.
no setterinherited
knownParticipants List<KnownParticipant>
final
msgLastRefresh int
final
noReply bool
final
onlyPrivateAnswers bool
final
parent UnparsedMessage
final
replies List<UnparsedMessage>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited