ConversationsParser class

Inheritance

Constructors

ConversationsParser(AppletContext ctx, {Future<bool> isConnected()?})

Properties

appletMeta AppletMeta
finalinherited
cachedCanChooseType bool?
getter/setter pair
ctx AppletContext
finalinherited
filter OverviewFiltering
latefinal
hashCode int
The hash code for this object.
no setterinherited
isConnected Future<bool> Function()
finalinherited
isEmpty bool
getter/setter pairinherited
latestResponse FetcherResponse<List<OverviewEntry>>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream AppletResponseStream<List<OverviewEntry>>
no setterinherited

Methods

addData(List<OverviewEntry> content) → void
Force pushes new data for the stream.
addResponse(FetcherResponse<List<OverviewEntry>> data) → void
inherited
canChooseType() Future<bool>
createConversation(List<String> receivers, String? type, String subject, String text) Future<CreationResponse>
Creates a new conversation.
dispose() → void
inherited
fetchData({bool forceRefresh = false, bool secondTry = false}) Future<void>
inherited
fixUsername(String username) String
getHome() Future<List<OverviewEntry>>
Gets the entries which you can see in the overview.
override
getSingleConversation(String uniqueID) Future<Conversation>
Gets a whole single conversation with statistics.
hideConversation(String id) Future<bool>
Hides the conversation id is the "Uniquid" of the conversation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshConversation(String uniqID, int lastRefresh) Future<ConversationsRefreshResult>
replyToConversation(String headId, String sender, String groupOnly, String privateAnswerOnly, String message) Future<ReplyToConversationResult>
Replies to an already existing conversation.
searchTeacher(String name) Future<List<ReceiverEntry>>
Searches for teachers using at least 2 chars.
showConversation(String id) Future<bool>
Shows a hidden conversation. id is the "Uniquid" of the conversation.
startAutoRefresh() → void
Starts periodic refresh. Safe to call repeatedly.
inherited
stopAutoRefresh() → void
Stops periodic refresh while the applet is off-screen.
inherited
timerCallback(Timer timer) → void
override
toggleSuspend() → void
toString() String
A string representation of this object.
inherited
typeFromJson(String json) List<OverviewEntry>
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited