ConversationsRefreshResult class

Constructors

ConversationsRefreshResult({required List<UnparsedMessage> messages, required int lastRefresh})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lastRefresh int
final
messages List<UnparsedMessage>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited