LessonUpload class

Constructors

LessonUpload({required String name, required String status, required Uri url, String? uploaded, String? date})

Properties

date String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
getter/setter pair
uploaded String?
getter/setter pair
url Uri
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited