OverviewEntry class

Constructors

OverviewEntry({required String id, required String title, required String? shortName, required String fullName, required String date, required bool unread, required bool hidden})
const
OverviewEntry.fromJson(Map<String, dynamic> json)

Properties

date String
final
fullName String
final
hashCode int
The hash code for this object.
no setteroverride
hidden bool
final
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortName String?
final
title String
final
unread bool
final

Methods

copyWith({String? id, String? title, String? shortName, String? fullName, String? date, bool? unread, bool? hidden}) OverviewEntry
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override