OwnFile class

Inheritance

Constructors

OwnFile({required String name, required String url, required String index, required String time, String? comment})

Properties

comment String?
final
hashCode int
The hash code for this object.
no setterinherited
index String
finalinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time String
final
url String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited