SphTimeOfDay class

Dart-only replacement for Flutter's TimeOfDay.

Implemented types

Constructors

SphTimeOfDay({required int hour, required int minute})
const
SphTimeOfDay.fromList(List parts)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
hour int
final
minute int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(SphTimeOfDay other) int
Compares this object to another object.
override
differenceInMinutes(SphTimeOfDay other) int
Minutes from this time until other (can be negative).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toList() List<int>
toString() String
A string representation of this object.
override

Operators

operator <(SphTimeOfDay other) bool
operator <=(SphTimeOfDay other) bool
operator ==(Object other) bool
The equality operator.
override
operator >(SphTimeOfDay other) bool
operator >=(SphTimeOfDay other) bool