StudentStudyGroup class

Constructors

StudentStudyGroup({required String id, required String semester, required String courseName, required List<StudentStudyGroupTeacher> teachers, required List<StudentStudyGroupExam> exams, required String courseSysId})

Properties

courseName String
final
courseSysId String
final
exams List<StudentStudyGroupExam>
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semester String
final
teachers List<StudentStudyGroupTeacher>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited