SubstitutionInfo class

A data class to store all information that is available to every user for a single substitution day This value is plain html

Constructors

SubstitutionInfo({required String header, required List<String> values})
SubstitutionInfo.fromJson(Map<String, dynamic> json)

Properties

hashCode int
The hash code for this object.
no setterinherited
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited