AccountSummary class
Account row without password (safe for lists).
Constructors
- AccountSummary({required int localId, required int schoolID, required String username, required String schoolName, AccountType? accountType, DateTime? lastLogin, required DateTime creationDate})
-
const
Properties
- accountType → AccountType?
-
final
- creationDate → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastLogin → DateTime?
-
final
- localId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schoolID → int
-
final
- schoolName → String
-
final
- username → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited