CalendarParser class
- Inheritance
-
- Object
- AppletParser<
List< CalendarEvent> > - CalendarParser
Constructors
-
CalendarParser(AppletContext ctx, {Future<
bool> isConnected()?})
Properties
- appletMeta → AppletMeta
-
finalinherited
- ctx → AppletContext
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isConnected
→ Future<
bool> Function() -
finalinherited
- isEmpty ↔ bool
-
getter/setter pairinherited
-
latestResponse
→ FetcherResponse<
List< ?CalendarEvent> > -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ AppletResponseStream<
List< CalendarEvent> > -
no setterinherited
Methods
-
addResponse(
FetcherResponse< List< data) → voidCalendarEvent> > -
inherited
-
dispose(
) → void -
inherited
-
fetchData(
{bool forceRefresh = false, bool secondTry = false}) → Future< void> -
inherited
-
getCalendar(
{required DateTime startDate, required DateTime endDate, String searchQuery = ''}) → Future< List< CalendarEvent> > -
getEvent(
String id) → Future< Map< String, dynamic> ?> -
getExports(
) → Future< ({String subscriptionLink, Set< int> years})> -
getHome(
) → Future< List< CalendarEvent> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startAutoRefresh(
) → void -
Starts periodic refresh. Safe to call repeatedly.
inherited
-
stopAutoRefresh(
) → void -
Stops periodic refresh while the applet is off-screen.
inherited
-
timerCallback(
Timer timer) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
typeFromJson(
String json) → List< CalendarEvent> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parseCategoriesHtml(
String html) → List< CalendarEventCategory> - Extract categories from kalender.php HTML.
-
parseEventsJson(
String body, List< CalendarEventCategory> categories) → List<CalendarEvent> - Parse the getEvents JSON body into CalendarEvents.