SubstitutionDay class
A data class to store all substitution information for a single day
Constructors
-
SubstitutionDay({required String parsedDate, List<
Substitution> ? substitutions, List<SubstitutionInfo> ? infos}) -
SubstitutionDay.fromJson(Map<
String, dynamic> json)
Properties
- dateTime → DateTime
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
infos
→ List<
SubstitutionInfo> ? -
final
- parsedDate → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
substitutions
→ List<
Substitution> -
final
Methods
-
add(
Substitution substitution) → void -
filterAll(
SubstitutionFilter filter) → void -
getDateTime(
) → DateTime -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
withDayInfo(
List< SubstitutionInfo> info) → SubstitutionDay
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited